pub enum Error {
Discovery(DiscoveryError),
Jwks(JwksError),
Registration(RegistrationError),
Authorization(AuthorizationError),
TokenAuthorizationCode(TokenAuthorizationCodeError),
TokenClientCredentials(TokenRequestError),
TokenRefresh(TokenRefreshError),
TokenRevoke(TokenRevokeError),
UserInfo(UserInfoError),
Introspection(IntrospectionError),
AccountManagement(AccountManagementError),
}Expand description
All possible errors when using this crate.
Variants
Discovery(DiscoveryError)
An error occurred fetching provider metadata.
Jwks(JwksError)
An error occurred fetching the provider JWKS.
Registration(RegistrationError)
An error occurred during client registration.
Authorization(AuthorizationError)
An error occurred building the authorization URL.
TokenAuthorizationCode(TokenAuthorizationCodeError)
An error occurred exchanging an authorization code for an access token.
TokenClientCredentials(TokenRequestError)
An error occurred requesting an access token with client credentials.
TokenRefresh(TokenRefreshError)
An error occurred refreshing an access token.
TokenRevoke(TokenRevokeError)
An error occurred revoking a token.
UserInfo(UserInfoError)
An error occurred requesting user info.
Introspection(IntrospectionError)
An error occurred introspecting a token.
AccountManagement(AccountManagementError)
An error occurred building the account management URL.